<?php
 /**
 * @package plg_jleditor
 * @author Arkadiy Sedelnikov(a.sedelmikov@gmail.com)
 * @version 1.0
 * @copyright (C) 2014 by JoomLine (http://www.joomline.ru)
 * @license GNU/GPL: http://www.gnu.org/copyleft/gpl.html
 *
*/
defined('_JEXEC') or die;

class PlgEditorJLEditor extends JPlugin
{
	public function onInit()
	{
        JHtml::_('jquery.framework');
        $doc = JFactory::getDocument();
        $lang = $this->getLang();
        $doc->addStyleSheet(JUri::root().'plugins/editors/jleditor/assets/css/smoothness/jquery-ui-1.10.4.custom.css');
        $doc->addStyleSheet(JUri::root().'plugins/editors/jleditor/assets/css/elrte.full.css');

        $doc->addScript(JUri::root().'plugins/editors/jleditor/assets/js/jquery-ui-1.10.4.custom.js');
        $doc->addScript(JUri::root().'plugins/editors/jleditor/assets/js/elrte.full.js');
        $doc->addScript(JUri::root().'plugins/editors/jleditor/assets/js/i18n/elrte.'.$lang.'.js');
    }

	public function onGetContent($editor)
	{
		return "jQuery('#$editor').elrte('val');";
	}

	public function onSetContent($editor, $html)
	{
        return "jQuery('#$editor').elrte('val', '$html');";
	}

	public function onSave($editor)
	{
        return "jQuery('#$editor').elrte('updateSource');";
	}

	public function onGetInsertMethod($name)
	{
		$doc = JFactory::getDocument();

        $js = "
			function jInsertEditorText( text, editor )
			{
				jQuery('#$name').elrte('insertHtml', text);
			}
			";

		$doc->addScriptDeclaration($js);

		return true;
	}

	public function onDisplay($name, $content, $width, $height, $col, $row, $buttons = true, $id = null, $asset = null, $author = null)
	{
        $doc = JFactory::getDocument();
        $app = JFactory::getApplication();

		if (empty($id))
		{
			$id = $name;
		}

        $lang = $this->getLang();
        $root = JUri::root(true);
        $root = (!empty($root)) ? $root : '/';


        $use_content_css	= $this->params->get('content_css', 1);
        $content_css_custom	= $this->params->get('content_css_custom', '');

        /*
         * Lets get the default template for the site application
         */
        $db		= JFactory::getDbo();
        $query	= $db->getQuery(true)
            ->select('template')
            ->from('#__template_styles')
            ->where('client_id=0 AND home=' . $db->quote('1'));

        $db->setQuery($query);
        $template = $db->loadResult();

        $content_css = '';

        $templates_path = JPATH_SITE . '/templates';

        // Loading of css file for 'styles' dropdown
        if ( $content_css_custom )
        {
            // If URL, just pass it to $content_css
            if (strpos($content_css_custom, 'http') !== false)
            {
                $content_css = 'cssfiles : ["' . $content_css_custom . '"],';
            }

            // If it is not a URL, assume it is a file name in the current template folder
            else
            {
                $content_css = 'cssfiles : ["' . $root . 'templates/' . $template . '/css/' . $content_css_custom . '"],';

                // Issue warning notice if the file is not found (but pass name to $content_css anyway to avoid TinyMCE error
                if (!file_exists($templates_path . '/' . $template . '/css/' . $content_css_custom))
                {
                    $msg = sprintf(JText::_('PLG_TINY_ERR_CUSTOMCSSFILENOTPRESENT'), $content_css_custom);
                    JLog::add($msg, JLog::WARNING, 'jerror');
                }
            }
        }
        else
        {
            // Process when use_content_css is Yes and no custom file given
            if ($use_content_css)
            {
                // First check templates folder for default template
                // if no editor.css file in templates folder, check system template folder
                if (!file_exists($templates_path . '/' . $template . '/css/editor.css'))
                {
                    // If no editor.css file in system folder, show alert
                    if (!file_exists($templates_path . '/system/css/editor.css'))
                    {
                        JLog::add(JText::_('PLG_TINY_ERR_EDITORCSSFILENOTPRESENT'), JLog::WARNING, 'jerror');
                    }
                    else
                    {
                        $content_css = 'cssfiles : ["' . $root . 'templates/system/css/editor.css"],';
                    }
                }
                else
                {
                    $content_css = 'cssfiles : ["' . $root . 'templates/' . $template . '/css/editor.css"],';
                }
            }
        }

        if($this->params->get('absolute_urls', '1'))
        {
            $absolute_urls = 'absoluteURLs : true,';
        }
        else
        {
            $absolute_urls = 'absoluteURLs : false,';
        }

        if($this->params->get('allow_source', '1'))
        {
            $allow_source = 'allowSource : true,';
        }
        else
        {
            $allow_source = 'allowSource : false,';
        }

        if(($this->params->get('fm_allow_front', '1') && !$app->isAdmin())
            ||($this->params->get('fm_allow_admin', '1') && $app->isAdmin()))
        {
            include_once JPATH_ROOT.'/administrator/components/com_jlfilemanager/helpers/jlfilemanager.php';

            $doc->addStyleSheet(JUri::root().'administrator/components/com_jlfilemanager/assets/elFinder/css/elfinder.min.css');
            $doc->addStyleSheet(JUri::root().'administrator/components/com_jlfilemanager/assets/elFinder/css/theme.css');
            $doc->addScript(JUri::root().'administrator/components/com_jlfilemanager/assets/elFinder/js/elfinder.min.js');

            if($lang != 'en'){
                $doc->addScript(JUri::root().'administrator/components/com_jlfilemanager/assets/elFinder/js/i18n/elfinder.'.$lang.'.js');
            }

            $token = JSession::getFormToken();
            JFactory::getApplication()->setUserState('com_jlfilemanager.token', $token);

            $comands = JLfilemanagerHelper::getComands();

            $fmAllow = "
            fmAllow : true,
            fmOpen : function(callback) {
                $('<div />').dialogelfinder({
                    url : '".JUri::root()."administrator/index.php?option=com_jlfilemanager&task=connector.run',
                    commandsOptions: {
                      getfile: {
                        oncomplete: 'destroy' // destroy elFinder after file selection
                      }
                    },
                    customData:{
                        token : '$token'
                    },
                    commands : [
                        $comands
                    ],
                    getFileCallback: callback // pass callback to file manager
                  });
                },
            ";
        }
        else{
            $fmAllow = 'fmAllow : false,';
        }

        if($app->isAdmin()){
            $toolbar = "toolbar: '".$this->params->get('admin_toolbar', 'maxi')."',";
        }
        else{
            $toolbar = "toolbar: '".$this->params->get('front_toolbar', 'tiny')."',";
        }


        $doc->addScriptDeclaration("
        (function($){
        $(document).ready(function() {
			var opts = {
				cssClass : 'el-rte',
				lang     : '$lang',
				$content_css
				$absolute_urls
				$allow_source
				$fmAllow
				$toolbar
				styleWithCSS : false,
				height : '$height',
				width : '$width'
			}
			$('#$id').elrte(opts);
		})
        })(jQuery);
        ");

        // Only add "px" to width and height if they are not given as a percentage
        if (is_numeric($width))
        {
            $width .= 'px';
        }

        if (is_numeric($height))
        {
            $height .= 'px';
        }

		// Data object for the layout
		$textarea = new stdClass;
		$textarea->name    = $name;
		$textarea->id      = $id;
		$textarea->cols    = $col;
		$textarea->rows    = $row;
		$textarea->width   = $width;
		$textarea->height  = $height;
		$textarea->content = $content;

		$editor = '<div class="editor">';
		$editor .= JLayoutHelper::render('joomla.tinymce.textarea', $textarea);
        $editor .= $this->_displayButtons($id, $buttons, $asset, $author);
		$editor .= '</div>';

		return $editor;
	}

    /**
     * Displays the editor buttons.
     *
     * @param   string  $name     The editor name
     * @param   mixed   $buttons  [array with button objects | boolean true to display buttons]
     * @param   string  $asset    The object asset
     * @param   object  $author   The author.
     *
     * @return  string HTML
     */
    private function _displayButtons($name, $buttons, $asset, $author)
    {
        $return = '';

        $args = array(
            'name'  => $name,
            'event' => 'onGetInsertMethod'
        );

        $results = (array) $this->update($args);

        if ($results)
        {
            foreach ($results as $result)
            {
                if (is_string($result) && trim($result))
                {
                    $return .= $result;
                }
            }
        }

        if (is_array($buttons) || (is_bool($buttons) && $buttons))
        {
            $buttons = $this->_subject->getButtons($name, $buttons, $asset, $author);

            $return .= JLayoutHelper::render('joomla.tinymce.buttons', $buttons);
        }

        return $return;
    }

    private function getLang()
    {
        $sysLang = JFactory::getLanguage()->getTag();
        $langs = array(
            'ar-DZ' => 'ar',
            'ca-ES' => 'ca',
            'cs-CZ' => 'cs',
            'da-DK' => 'da',
            'de-DE' => 'de',
            'en-GB' => 'en',
            'es-ES' => 'es',
            'fa-IR' => 'fa',
            'fr-FR' => 'fr',
            'hr-HR' => 'hr',
            'hu-HU' => 'hu',
            'ja-JP' => 'jp',
            'ko-KR' => 'ko',
            'lv-LV' => 'lv',
            'nl-NL' => 'nl',
            'pl-PL' => 'pl',
            'pt-BR' => 'pt_BR',
            'ru-RU' => 'ru',
            'sk-SK' => 'sk',
            'th-TH' => 'th',
            'tr-TR' => 'tr',
            'uk-UA' => 'uk',
            'vi-VN' => 'vi',
            'zh-CN' => 'zh_CN',
            'zh-TW' => 'zh_TW',
        );

        return (in_array($sysLang, $langs)) ? $langs[$sysLang] : 'en';
    }
}
